@@ -13,7 +13,7 @@ use strict;
 use 5.008001;
 use base 'URI::Nested';
 use URI::_db;
-our $VERSION = '0.22';
+our $VERSION = '0.23';
 
 sub prefix       { 'db' }
 sub nested_class { 'URI::_db' }
@@ -282,7 +282,7 @@ DBI DSN. Some examples:
   | URI                                  | DSN                                              |
   |--------------------------------------+--------------------------------------------------|
   | db:pg:try                            | dbi:Pg:dbname=try                                |
-  | db:mysql://localhost:33/foo          | dbi:mysql:host=localhost;port=33;database=foo    |
+  | db:mysql://localhost:33/foo          | dbi:MariaDB:host=localhost;port=33;database=foo    |
   | db:db2://localhost:33/foo            | dbi:DB2:HOSTNAME=localhost;PORT=33;DATABASE=foo  |
   | db:vertica:dbadmin                   | dbi:ODBC:DSN=dbadmin                             |
   | db:mssql://foo.com/pubs?Driver=MSSQL | dbi:ODBC:Host=foo.com;Database=pubs;Driver=MSSQL |
